ui/component/component library
Classes
- Clickable
- CustomRefreshIndicator
- DashedLinePainter
- ImageView
- InfiniteScrollWidget
- Line
- PressableContainer
- ScrollToHide
- A widget that hides its child when the user scrolls down and shows it again when the user scrolls up. This behavior is commonly used to hide elements like a bottom navigation bar to provide a more immersive user experience.
- TimerView